import { FollowButton } from "@/components/follow-button"
import { UserAvatar } from "@/components/user-avatar"
import Link from "next/link"
import { IUser } from "../types"
import { following } from "../utils/following"

export const UserItem = async ({ user, sessionId }: { user: IUser, sessionId: string | undefined }) => {
    const isFollowing = following({
        user,
        sessionUserId: sessionId ? sessionId : "",
    })

    return (
        <Link
            href={`/${user?.username}`}
            className="flex flex-row flex-shrink gap-3 hover:bg-accent active:bg-accent rounded-lg p-3 items-center">

            <UserAvatar
                user={{ username: user.username, image: user.image || null }}
                className="h-12 w-12 aspect-square"
            />

            <div className="flex flex-col flex-shrink justify-center h-full w-full space-y-3 overflow-hidden">
                <div className="flex justify-between">
                    <div className="whitespace-nowrap">
                        <h1 className="font-bold">{user.name}</h1>
                        <h1 className="text-sm text-sky-500">@{user.username}</h1>
                    </div>

                    {/* TODO does not refresh button when following or unfolling */}
                    {/* {sessionId && sessionId !== user.id &&
                        <FollowButton
                            userId={user.id}
                            username={user.username ? user.username : ""}
                            isFollowing={isFollowing}
                        />
                    } */}
                </div>

                {user.bio ? (<p className="truncate w-full">{user.bio}</p>) : <p>&nbsp;</p>}
            </div>
        </Link>
    )
}
